@@ -1,6 +1,5 @@
 /*
     Redactor v7.6.3
-    Updated 31.05.2012
     
     http://redactorjs.com/
         
@@ -176,6 +175,15 @@ var RTOOLBAR = {};
                                 '<td>%__.text%</td>' +
                                 '<td><input class="redactor_link_text" id="redactor_link_url_text" style="width: 99%; font-size: 16px;" /></td>' +
                             '</tr>' +
+                            '<tr>' +
+                                '<td>Target</td>' +
+                                '<td>' +
+                                    '<select id="redactor_link_target">' +
+                                        '<option value="_self" style="width: 99%; font-size: 16px;" > Self </option>' +
+                                        '<option value="_blank" style="width: 99%; font-size: 16px;" > Blank </option>' +
+                                    '</select>' +
+                                '</td>' +
+                            '</tr>' +
                         '</table>' +
                     '</div>' +
                     '<div class="redactor_tab" id="redactor_tab2" style="display: none;">' +
@@ -1915,7 +1923,7 @@ var RTOOLBAR = {};
         {
             var tab_selected = $('#redactor_tab_selected').val();
             
-            var link = '', text = '';
+            var link = '', text = '', target = '';
             
             if (tab_selected == 1) // url
             {
@@ -1932,8 +1940,10 @@ var RTOOLBAR = {};
                 link = '#' + $('#redactor_link_anchor').val();
                 text = $('#redactor_link_anchor_text').val();
             }
+            
+            target = $('#redactor_link_target').val();
 
-            this._insertLink('<a href="' + link + '">' +  text + '</a> ', $.trim(text), link);
+            this._insertLink('<a href="' + link + '" target="' + target + '">' +  text + '</a> ', $.trim(text), link);
 
         },
         insertLinkFile: function(data)
